@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright: (c) 2019, Jordan Borean (@jborean93) <jborean93@gmail.com>
 # MIT License (see LICENSE or https://opensource.org/licenses/MIT)
 
@@ -9,7 +8,7 @@ from smbprotocol._text import to_bytes, to_text
 from smbprotocol.structure import BytesField, EnumField, IntField, Structure
 
 
-class ReparseTags(object):
+class ReparseTags:
     """
     [MS-FSCC] 2.1.2.1 Reparse Tags
     https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-fscc/c8e77b37-3909-4fe6-a4ea-2b9d423b1ee4
@@ -97,7 +96,7 @@ class ReparseTags(object):
         return tag & 0x10000000 == 0x10000000
 
 
-class SymbolicLinkFlags(object):
+class SymbolicLinkFlags:
     """
     [MS-FSCC] 2.1.2.4 Symbolic Link Reparse Data Buffer - Flags
     https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-fscc/b41f1cbf-10df-4a47-98d4-1c52a833d913
@@ -135,7 +134,7 @@ class ReparseDataBuffer(Structure):
                 ("data_buffer", BytesField(size=lambda s: s["reparse_data_length"].get_value())),
             ]
         )
-        super(ReparseDataBuffer, self).__init__()
+        super().__init__()
 
 
 class SymbolicLinkReparseDataBuffer(Structure):
@@ -168,7 +167,7 @@ class SymbolicLinkReparseDataBuffer(Structure):
                 ),
             ]
         )
-        super(SymbolicLinkReparseDataBuffer, self).__init__()
+        super().__init__()
 
     def get_substitute_name(self):
         return self._get_name("substitute")
@@ -201,7 +200,7 @@ class SymbolicLinkReparseDataBuffer(Structure):
         return ntpath.abspath(link_target)
 
     def _get_name(self, prefix):
-        offset = self["%s_name_offset" % prefix].get_value()
-        length = self["%s_name_length" % prefix].get_value()
+        offset = self[f"{prefix}_name_offset"].get_value()
+        length = self[f"{prefix}_name_length"].get_value()
         b_name = self["buffer"].get_value()[offset : offset + length]
         return to_text(b_name, encoding="utf-16-le")
